The traits Observable and Observer construct the typical observer-pattern.
The messages parsed in between Observable and Observer is the generic variable T.
Because keeping track of all Observers when implementing Observable can be hard,
this module also contains a ObserverList where Observers can be
attached, detached and
notified.
Structs
- Observer
List - A list of Observer
using the message T.
Traits
- Observable
- A Observable that can be observed by Observer
. - Observer
- A Observer observing a Observable
.